Module buffer

Module buffer 

Define the buffer interface for reading data in different situations

Structs

BufferReader
CommonBuffer

Traits

BufferGetter
BufferedReader
This trait is used for buffered reads where the packet length is not known
DynamicSizeBuffer
Buffer for situations where the length of the data to be read is not known
FixedSizeBuffer
Buffer for situations where the length of the data to be read is already known