pub enum LocalServer {
Stream {
client_id: u32,
server_generation: u64,
},
Pong,
PongV2 {
seq: u64,
},
Retire {
reason: String,
conn_id: u32,
server_generation: u64,
},
}Variants
Stream
pb server makes a stream request to local server
Pong
pb server response a pong msg when it receive a ping request
PongV2
Retire