Define the buffer interface for reading data in different situations
Structs
Traits
- Buffer
Getter - Buffered
Reader - This trait is used for buffered reads where the packet length is not known
- Dynamic
Size Buffer - Buffer for situations where the length of the data to be read is not known
- Fixed
Size Buffer - Buffer for situations where the length of the data to be read is already known