pub trait FixedSizeBuffer {
// Required method
fn fixed_resize(&mut self, size: usize);
}Expand description
Buffer for situations where the length of the data to be read is already known
Required Methods
Sourcefn fixed_resize(&mut self, size: usize)
fn fixed_resize(&mut self, size: usize)
The length of the buffer must reach size after resize, as opposed to
DynamicSizeBuffer’s internal state-based resize.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".