pub struct CodecMessageWriter<'a, T: AsyncWriteExt + Unpin, E: Encryptor> { /* private fields */ }Expand description
NOTE: We copy input data before encryption to avoid mutating shared buffers. This trades some performance for correctness until a zero-copy mutable API is added.
Implementations
Sourceimpl<'a, T: AsyncWriteExt + Unpin, E: Encryptor> CodecMessageWriter<'a, T, E>
impl<'a, T: AsyncWriteExt + Unpin, E: Encryptor> CodecMessageWriter<'a, T, E>
pub fn new(writer: &'a mut T, encryptor: E) -> Self
pub fn for_session_key(writer: &'a mut T, encryptor: E, key: AesKeyType) -> Self
pub fn with_checksum_key(self, key: AesKeyType) -> Self
pub async fn shutdown(&mut self) -> Result<()>